( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-generic-smp-2.6.17.13 System.map )
( cd boot ; rm -rf config )
( cd boot ; ln -sf config-generic-smp-2.6.17.13 config )
( cd boot ; rm -rf vmlinuz )
( cd boot ; ln -sf vmlinuz-generic-smp-2.6.17.13 vmlinuz )
